#include <iostream>
#include <set>
#include <vector>
#include <map>
#include <unordered_map>
#include <utility>
#include <cmath>
#include <queue>
#include <algorithm>
#include <memory>
#include <iomanip>

template<typename T>
T make_vector() {
    return T();
}

template<typename T, typename V, typename... Args>
auto make_vector(V v, Args... args) {
    return std::vector(v, make_vector<T>(args...));
}

template<typename... Args>
void read(Args &... args) {
    (std::cin >> ... >> args);
}

void print() {
    std::cout << '\n';
}

template<typename T, typename... Args>
void print(T &&t, Args &&... args) {
    std::cout << std::forward<T>(t) << ' ';
    print(std::forward<Args>(args)...);
}

using namespace std;

const int N = 1003;

const int dx[] = {-1, 0, 1, 0};
const int dy[] = {0, 1, 0, -1};


int n, m;
char f[N][N];
int components;
int color[N][N];
int nearest[N][N][4];
pair<int, int> wall[N * N];
bool used[N * N];
int dist[N * N];
int edgeToMe[N * N];
int edgeDir[N * N];
int ancComp[N * N];
pair<int, int> shootFrom[N * N];


vector<string> ans;

vector<pair<int, int>> g[N * N];

bool ok(int x, int y) {
    return x >= 0 && y >= 0 && x < n && y < m;
}

void paint(int x, int y, int c) {
    color[x][y] = c;
    for (int i = 0; i < 4; i++) {
        int nx = x + dx[i];
        int ny = y + dy[i];
        if (ok(nx, ny)) {
            if (f[nx][ny] == '.' && color[nx][ny] == 0) {
                paint(nx, ny, c);
            }
            if (f[nx][ny] == 'W') {
                wall[c] = make_pair(x, y);
            }
        }
    }
}

int lastRun = 0;
int lastUpdate[N][N];
int dirGoToCeil[N][N];


void dfsGoToCeil(int x, int y) {
    lastUpdate[x][y] = lastRun;
    for (int i = 0; i < 4; i++) {
        int nx = x + dx[i];
        int ny = y + dy[i];
        if (f[nx][ny] != '.' || lastUpdate[nx][ny] == lastRun) {
            continue;
        }
        dirGoToCeil[nx][ny] = i + 1;
        dfsGoToCeil(nx, ny);
    }
}

void gotoCeil(int &x, int &y, int toX, int toY) {
    lastRun++;
    dfsGoToCeil(x, y);
    vector<string> path;
    int saveToX = toX;
    int saveToY = toY;
//    if (x == 5 && y == 3 && toX == 1 && toY == 1) {
//        cout << endl;
//        for (int i = 0; i < n; i++){
//            for (int j = 0 ;j < m; j++) {
//                cout << dirGoToCeil[i][j] << ' ';
//            }
//            cout << endl;
//        }
//        exit(0);
//    }

    while (toX != x || toY != y) {

//        cerr << toX << ' ' << toY << ' ' << x << ' ' << y << endl;
        switch (dirGoToCeil[toX][toY]) {
            case 1:
                toX++;
                path.push_back("MU");
                break;
            case 2:
                toY--;
                path.push_back("MR");
                break;
            case 3:
                toX--;
                path.push_back("MD");
                break;
            case 4:
                toY++;
                path.push_back("ML");
                break;
        }
    }
    reverse(path.begin(), path.end());
    ans.insert(ans.end(), path.begin(), path.end());
    x = saveToX;
    y = saveToY;
}


const string DIR_TO_CHAR[] = {"U", "R", "D", "L"};
int lastShotDir;
//int portalX;
//int portalY;

bool blueOrange = false;

void shoot(int dir) {
    if (blueOrange) {
        ans.push_back("O" + DIR_TO_CHAR[dir]);
        lastShotDir = dir;
    } else {
        ans.push_back("B" + DIR_TO_CHAR[dir]);
        lastShotDir = dir;
    }
    blueOrange ^= true;
}

void gotoWall(int &x, int &y) {
    gotoCeil(x, y, wall[color[x][y]].first, wall[color[x][y]].second);
    for (int i = 0; i < 4; i++) {
        int nx = x + dx[i];
        int ny = y + dy[i];
        if (f[nx][ny] == 'W') {
            shoot(i);
//            portalX = x;
//            portalY = y;
            return;
        }
    }
}

int main() {
    std::ios::sync_with_stdio(false);
    std::cin.tie(nullptr);
#ifdef HOME
    std::freopen("input.txt", "rt", stdin);
#endif
    cin >> n >> m;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            cin >> f[i][j];
        }
    }
    components = 0;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (f[i][j] == '.') {
                if (color[i][j] == 0) {
                    paint(i, j, ++components);
                }
            } else {
                color[i][j] = -1;
            }
        }
    }
//    for (int i = 0; i < n; i++) {
//        for (int j = 0; j < m; j++) {
//            cout << setw(2) << color[i][j] << ' ';
//        }
//        cout << endl;
//    }

    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (f[i][j] == 'W') {
                nearest[i][j][3] = j;
            } else {
                nearest[i][j][3] = nearest[i][j - 1][3];
            }
        }
    }

    for (int i = 0; i < n; i++) {
        for (int j = m - 1; j >= 0; j--) {
            if (f[i][j] == 'W') {
                nearest[i][j][1] = j;
            } else {
                nearest[i][j][1] = nearest[i][j + 1][1];
            }
        }
    }

    for (int j = 0; j < m; j++) {
        for (int i = 0; i < n; i++) {
            if (f[i][j] == 'W') {
                nearest[i][j][0] = i;
            } else {
                nearest[i][j][0] = nearest[i - 1][j][0];
            }
        }
    }

    for (int j = 0; j < m; j++) {
        for (int i = n - 1; i >= 0; i--) {
            if (f[i][j] == 'W') {
                nearest[i][j][2] = i;
            } else {
                nearest[i][j][2] = nearest[i + 1][j][2];
            }
        }
    }

    int numberOfEdges = 0;
    for (int i = 0; i < n; i++) {
        for (int j = 0; j < m; j++) {
            if (f[i][j] != '.' || wall[color[i][j]] == make_pair(0, 0)) {
                continue;
            }
            int x, y;
            x = nearest[i][j][0] + 1;
            if (color[x][j] != -1 && color[x][j] != color[i][j]) {
                g[color[i][j]].emplace_back(color[x][j], numberOfEdges);
                edgeDir[numberOfEdges] = 0;
                shootFrom[numberOfEdges++] = make_pair(i, j);
            }
            x = nearest[i][j][2] - 1;
            if (color[x][j] != -1 && color[x][j] != color[i][j]) {
                g[color[i][j]].emplace_back(color[x][j], numberOfEdges);
                edgeDir[numberOfEdges] = 2;
                shootFrom[numberOfEdges++] = make_pair(i, j);
            }
            y = nearest[i][j][1] - 1;
            if (color[i][y] != -1 && color[i][y] != color[i][j]) {
                g[color[i][j]].emplace_back(color[i][y], numberOfEdges);
                edgeDir[numberOfEdges] = 1;
                shootFrom[numberOfEdges++] = make_pair(i, j);
            }
            y = nearest[i][j][3] + 1;
            if (color[i][y] != -1 && color[i][y] != color[i][j]) {
                g[color[i][j]].emplace_back(color[i][y], numberOfEdges);
                edgeDir[numberOfEdges] = 3;
                shootFrom[numberOfEdges++] = make_pair(i, j);
            }
        }
    }

//    for (int i = 1; i <= components; i++) {
//        cout << i << endl;
//        for (auto e : g[i]) {
//            cout << e.first <<  ' ';
//        }
//        cout << endl;
//    }

    int sx, sy, fx, fy;
    cin >> sx >> sy >> fx >> fy;
    sx--, sy--, fx--, fy--;

    if (sx == fx && sy == fy) {
        cout << "0 0\n";
        return 0;
    }

    int sv = color[sx][sy];
    int fv = color[fx][fy];

    queue<int> q;
    q.push(sv);
    used[sv] = true;
    dist[sv] = 0;
    while (!q.empty()) {
        int v = q.front();
//        cout << v << endl;
        q.pop();
        for (pair<int, int> &e : g[v]) {
            if (used[e.first]) {
                continue;
            }
            dist[e.first] = dist[v] + 1;
            edgeToMe[e.first] = e.second;
            ancComp[e.first] = v;
            used[e.first] = true;
            q.push(e.first);
        }
    }
    if (!used[fv]) {
        cout << "-1 -1\n";
        return 0;
    }
    vector<int> path;
    for (int v = fv; v != sv; v = ancComp[v]) {
        path.push_back(v);
    }
    reverse(path.begin(), path.end());

    cout << dist[fv] + (dist[fv] != 0) << ' ';
    if (color[sx][sy] != color[fx][fy]) {
        gotoWall(sx, sy);
        int wallX = sx;
        int wallY = sy;
        int shotDir = lastShotDir;

        int edgeId = edgeToMe[path.front()];
//        cout << sx << ' ' << sy << ' ' << shootFrom[edgeId].first << " " << shootFrom[edgeId].second << endl;
        gotoCeil(sx, sy, shootFrom[edgeId].first, shootFrom[edgeId].second);
        shoot(edgeDir[edgeId]);
        int saveX = sx;
        int saveY = sy;
        gotoCeil(sx, sy, wallX, wallY);
//        cout << sx << ' ' << sy << ' ' << shootFrom[edgeId].first << " " << shootFrom[edgeId].second << endl;
        ans.push_back("M" + DIR_TO_CHAR[shotDir]);

        pair<int, int> newPos;
        switch (edgeDir[edgeId]) {
            case 0:
                newPos = make_pair(nearest[saveX][saveY][0] + 1, saveY);
                break;
            case 1:
                newPos = make_pair(saveX, nearest[saveX][saveY][1] - 1);
                break;
            case 2:
                newPos = make_pair(nearest[saveX][saveY][2] - 1, saveY);
                break;
            case 3:
                newPos = make_pair(saveX, nearest[saveX][saveY][3] + 1);
                break;
        }
        sx = newPos.first;
        sy = newPos.second;
//        portalX = sx;
//        portalY = sy;

    }

    int compId = 1;
    while(color[sx][sy] != color[fx][fy]) {
//        cout << sx << ' ' << sy << endl;
        int edgeId = edgeToMe[path[compId]];
        int portalX = sx;
        int portalY = sy;
        int portalDir = lastShotDir;
        gotoCeil(sx, sy, shootFrom[edgeId].first, shootFrom[edgeId].second);
        shoot(edgeDir[edgeId]);

        pair<int, int> newPos;
        switch (edgeDir[edgeId]) {
            case 0:
                newPos = make_pair(nearest[sx][sy][0] + 1, sy);
                break;
            case 1:
                newPos = make_pair(sx, nearest[sx][sy][1] - 1);
                break;
            case 2:
                newPos = make_pair(nearest[sx][sy][2] - 1, sy);
                break;
            case 3:
                newPos = make_pair(sx, nearest[sx][sy][3] + 1);
                break;
        }

        gotoCeil(sx, sy, portalX, portalY);
        ans.push_back("M" + DIR_TO_CHAR[portalDir]);

        sx = newPos.first;
        sy = newPos.second;
        compId++;
    }


    gotoCeil(sx, sy, fx, fy);

    cout << ans.size() - (dist[fv] + (dist[fv] != 0))  << endl;
    for (string &s : ans) {
        cout << s << '\n';
    }
}
