#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <queue>
#include <stack>
#include <map>
#include <iomanip>
#include <unordered_map>
#include <unordered_set>
#include <cmath>
#include <cassert>
#include <bitset>

using namespace std;

typedef long long ll;
typedef unsigned int ui;
typedef long double ld;
typedef pair<int, int> pii;

const int inf = 1e9;

const int N = 2e5 + 5;
const int A = 26;
const int SQRT = 300;
const int ITER = N / SQRT + 5;

int n, q;
string words[N];
pii queries[N];
int fast_res[N], sz;
int nxt[N][A];
int parent[N];
int where_word[N];
int S[N];
int depth[N];

void init() {
    sz = 1;
    fill((int*) nxt, (int*) nxt + N * A, -1);
    fill(parent, parent + N, -1);
    fill(S, S + N, 0);
}

void add_word(int i) {
    int v = 0;
    S[v]++;
    for (char c : words[i]) {
        c -= 'a';
        if (nxt[v][c] == -1) {
            parent[sz] = v;
            depth[sz] = depth[v] + 1;
            nxt[v][c] = sz++;
        }
        v = nxt[v][c];
        S[v]++;
    }
    where_word[i] = v;
}

int path[N], path_sz;
vector<int> qs_to_solve[N];
int mem[N][SQRT];
int to_push[N][SQRT];

void dfs(int v) {
    path[path_sz++] = v;
    if (v) {
        for (int k = 1; k < SQRT; k++) {
            mem[v][k] = mem[ parent[v] ][k];
            mem[v][k] = min(mem[v][k], (S[v] - 1) / k + depth[v] - 1);
        }
    } else {
        for (int k = 1; k < SQRT; k++) {
            mem[v][k] = inf;
            to_push[v][k] = 0;
        }
    }
    for (int qid : qs_to_solve[v]) {
        int k = queries[qid].second;
        int t = path_sz - 2, pu = 0;
        if (k >= SQRT) {
            int mxj = min(path_sz - 1, ITER);
            for (int j = 1; j < mxj; j++) {
                int vertex = path[j];
                t = min(t, (S[vertex] - 1) / k + depth[vertex] - 1);
            }
            for (int j = 0; j <= t; j++) {
                int f1, f2;
                f1 = path[j];
                f2 = path[j + 1];
                pu -= min(pu, S[f1] - S[f2]);
                pu += k;
            }
        } else {
            t = min(t, mem[v][k]);
            pu = to_push[path[t + 1]][k];
        }
        pu -= k;
        fast_res[qid] = t * k + min(k, S[path[t + 1]] - pu);
//        fast_res[qid] = pu;
    }
    for (int c = 0; c < A; c++) {
        if (nxt[v][c] == -1) {
            continue;
        }
        int to = nxt[v][c];
        for (int k = 1; k < SQRT; k++) {
            int pu = to_push[v][k];
            pu -= min(pu, S[v] - S[to]);
            pu += k;
            to_push[to][k] = pu;
        }
        dfs(to);
    }
    path_sz--;
}

void fast() {
    init();
    for (int i = 1; i <= n; i++) {
        add_word(i);
    }
    for (int i = 0; i < sz; i++) {
        qs_to_solve[i].clear();
    }
    for (int i = 1; i <= q; i++) {
        int word_id = queries[i].first;
        int vertex_id = where_word[word_id];
        qs_to_solve[vertex_id].push_back(i);
    }
    path_sz = 0;
    dfs(0);
}

void read() {
    cin >> n;
    for (int i = 1; i <= n; i++) {
        cin >> words[i];
    }
    cin >> q;
    for (int w, k, i = 1; i <= q; i++) {
        cin >> w >> k;
        queries[i] = {w, k};
    }
}

void WORK() {
    read();
    fast();
    for (int i = 1; i <= q; i++) {
        cout << fast_res[i] << "\n";
    }
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0); cout.tie(0);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
#endif

    WORK();

    return 0;
}