#include <iostream>
#include <algorithm>
#include <vector>
#include <set>
#include <queue>
#include <stack>
#include <map>
#include <iomanip>
#include <unordered_map>
#include <unordered_set>
#include <cmath>
#include <cassert>
#include <bitset>

using namespace std;

typedef long long ll;
typedef unsigned int ui;
typedef long double ld;
typedef pair<int, int> pii;

ll gcd(ll x, ll y) {
    return !x ? y : gcd(y % x, x);
}

struct Q {
    ll u = 0, v = 1;

    Q() = default;

    Q(ll uu, ll vv = 1) {
        u = uu;
        v = vv;
        norm();
    }

    void norm() {
        if (v < 0) {
            v = -v;
            u = -u;
        }
        ll g = gcd(u >= 0 ? u : -u, v);
        u /= g;
        v /= g;
    }

    bool operator < (const Q& o) const {
        return ld(u) * o.v < ld(o.u) * v;
    }

    bool operator == (Q o) {
        norm();
        o.norm();
        return u == o.u && v == o.v;
    }

    Q operator - (const Q& o) const {
        return Q(u * o.v - o.u * v, v * o.v);
    }

    Q operator + (const Q& o) const {
        return Q(u * o.v + o.u * v, v * o.v);
    }

    Q operator / (const Q& o) const {
        ll x1 = u;
        ll x2 = o.v;

        ll y1 = v;
        ll y2 = o.u;

        ll g = gcd(x1, y2);
        x1 /= g;
        y2 /= g;

        g = gcd(x2, y1);
        x2 /= g;
        y1 /= g;

        return Q(x1 * x2, y1 * y2);
    }



    Q operator * (const Q& o) const {
        ll x1 = u;
        ll x2 = o.u;

        ll y1 = v;
        ll y2 = o.v;

        ll g = gcd(x1, y2);
        x1 /= g;
        y2 /= g;

        g = gcd(x2, y1);
        x2 /= g;
        y1 /= g;

        return Q(x1 * x2, y1 * y2);
    }

    ll floor() const {
        if (u >= 0) {
            return u / v;
        } else {
            return (u % v == 0 ? u / v : u / v - 1);
        }
    }

    ll ceil() const {
        if (u >= 0) {
            return (u % v == 0 ? u / v : u / v + 1);
        } else {
            return u / v;
        }
    }

    Q operator - () const {
        return Q(-u, v);
    }

    void show() {
        cout << u << "/" << v;
    }
};

struct Line {
    Q k, b;
};

// min
struct CHT {
    deque<Line> st;

    void add_line(Line L) {
        if (!st.empty() && st.back().k == L.k) return;
        while ((int) st.size() > 1) {
            Line L1 = st[(int) st.size() - 2];
            Line L2 = st[(int) st.size() - 1];
            if ((L2.b - L1.b) / (L1.k - L2.k) < (L.b - L2.b) / (L2.k - L.k)) {
                break;
            }
            st.pop_back();
        }
        st.push_back(L);
    }

    void pop_line(Q x) {
        while ((int) st.size() > 1) {
            Line L1 = st[0];
            Line L2 = st[1];
            if (x < (L2.b - L1.b) / (L1.k - L2.k)) break;
            st.pop_front();
        }
    }

    Q get(Q x) {
        Line L = st[0];
        return L.k * x + L.b;
    }

    void show() {
        for (Line line : st) {
            cout << "y = ";
            line.k.show();
            cout << " * x + ";
            line.b.show();
            cout << "\n";
        }
    }
};

CHT build_cht(vector<Line> lines) {
    sort(lines.begin(), lines.end(), [](Line l1, Line l2) {
        return l2.k < l1.k || ((l1.k == l2.k) && l1.b < l2.b);
    });
    CHT cht;
    for (const Line& line : lines) {
        cht.add_line(line);
    }
    return cht;
}

int main() {
    ios_base::sync_with_stdio(false);
    cin.tie(0); cout.tie(0);
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
#endif

    ll lx = 0, ly = 0, rx, ry;
    int n;
    cin >> rx >> ry >> n;

    vector<pii> p(n);

    for (int x, y, i = 0; i < n; i++) {
        cin >> x >> y;
        p[i] = {x, y};
    }

    vector<Line> up, down;

    for (int i = 1; i < n; i++) {
        ll x1, y1, x2, y2;
        tie(x1, y1) = p[0];
        tie(x2, y2) = p[i];

        if (y1 == y2) {
            if (x2 > x1) {
                rx = min(rx, (x1 + x2) / 2);
            } else {
                lx = max(lx, (x1 + x2 + 1) / 2);
            }
            continue;
        } else {
            Q A(2 * (x2 - x1));
            Q B(2 * (y2 - y1));
            Q C(x2 * x2 - x1 * x1 + y2 * y2 - y1 * y1);
            C = -C;
            Q k = (-A) / B;
            Q b = (-C) / B;
            if (y2 > y1) {
                up.push_back({k, b});
            } else {
                k = -k;
                b = -b;
                down.push_back({k, b});
            }
        }
    }

    if (lx > rx) {
        cout << "0\n";
        return 0;
    }

    if (up.empty() && down.empty()) {
        cout << 1ll * (rx - lx + 1) * (ry - ly + 1) << "\n";
        return 0;
    }

    CHT cht_up = build_cht(up);
    CHT cht_down = build_cht(down);

//    cht_up.show();
//    cout << "\n=========\n";
//    cht_down.show();
//    cout << "\n=========\n";

    ll res = 0;

    for (ll x = lx; x <= rx; x++) {
        cht_up.pop_line(Q(x));
        cht_down.pop_line(Q(x));

        ll lq = 0;
        ll rq = ry;

        if (!cht_up.st.empty()) {
            rq = min(rq, cht_up.get(x).floor());
        }

        if (!cht_down.st.empty()) {
            lq = max(lq, (-cht_down.get(x)).ceil());
        }

        if (lq <= rq) {
            res += rq - lq + 1;
        }
    }

    cout << res << "\n";

    return 0;
}