#include <cassert>
#include <iostream>
#include <vector>
#include <set>
#include <queue>
#include <stack>
#include <math.h>
#include <random>
#include <chrono>
#include <map>
#include <functional>
using namespace std;

typedef long long ll;
typedef unsigned long long ull;

const int INF = 1000 * 1000 * 1000;
const ll LLINF = 1LL * INF * INF;

mt19937 gen(chrono::high_resolution_clock::now().time_since_epoch().count());

#define maxn 1010
int n, m;
int sr, sc, fr, fc; 
string grid[maxn];

int dr[] = { -1, 0, 1, 0 };
int dc[] = { 0, -1, 0, 1 };
char ds[] = { 'U', 'L', 'D', 'R' };

pair<int, int> parent[maxn][maxn];
int vis[maxn][maxn];
int cur_ok = 0;
void clear_parent() {
	for (int i = 0; i < n; ++i) for (int f = 0; f < m; ++f) parent[i][f] = { -1, -1 };
}

pair<int, int> bfs_grid(int r, int c, function<bool(int, int)> criteria) {
	++cur_ok;
	parent[r][c] = { r, c };
	queue<pair<int, int>> qu;
	vis[r][c] = cur_ok;
	for (qu.emplace(r, c); qu.size(); qu.pop()) {
		auto u = qu.front();
		if (criteria(u.first, u.second)) return u;
		for (int dir = 0; dir < 4; ++dir) {
			pair<int, int> v(u.first + dr[dir], u.second + dc[dir]);
			if (grid[v.first][v.second] != '.') continue;
			if (vis[v.first][v.second] == cur_ok) continue;
			parent[v.first][v.second] = u;
			vis[v.first][v.second] = cur_ok;
			qu.push(v);
		}
	}
	return { -1, -1 };
}

pair<int, int> dsu[maxn][maxn];
pair<int, int> findp(int r, int c) { return dsu[r][c] == make_pair(r, c) ? make_pair(r, c) : findp(dsu[r][c].first, dsu[r][c].second);  }

void join(int r1, int c1, int r2, int c2) {
	auto u = findp(r1, c1), v = findp(r2, c2);
	dsu[u.first][u.second] = v;
}

struct edge {
	pair<int, int> from, to;
	edge() {}
	edge(int fr, int fc, int tr, int tc) : from(fr, fc), to(tr, tc) {}
};
map<pair<int, int>, edge> gr[maxn][maxn];

int dis[maxn][maxn];
void bfs_block(int r, int c) {
	parent[r][c] = { r, c };
	dis[r][c] = 0;
	queue<pair<int, int>> qu;
	++cur_ok;
	vis[r][c] = cur_ok;
	for (qu.emplace(r, c); qu.size(); qu.pop()) {
		auto u = qu.front();
		for (auto& i : gr[u.first][u.second]) {
			auto v = i.first;
			if (vis[v.first][v.second] == cur_ok) continue;
			parent[v.first][v.second] = u;
			dis[v.first][v.second] = dis[u.first][u.second] + 1;
			vis[v.first][v.second] = cur_ok;
			qu.push(v);
		}
	}
}

char find_rel_place(int r1, int c1, int r2, int c2) {
	if (r2 < r1) return 'U';
	if (r2 > r1) return 'D';
	if (c2 < c1) return 'L';
	if (c2 > c1) return 'R';
}

vector<string> grid_path;
void get_back_path(pair<int, int> src, pair<int, int> dst) {
	vector<string> rev_path;
	for (auto cur = dst; cur != src; cur = parent[cur.first][cur.second]) {
		auto p = parent[cur.first][cur.second];
		rev_path.emplace_back(string("M") + find_rel_place(p.first, p.second, cur.first, cur.second));
	}
	grid_path.insert(grid_path.end(), rev_path.rbegin(), rev_path.rend());
}
pair<int, int> go(pair<int, int> from_point, pair<int, int> to_block) {
	auto from_block = findp(from_point.first, from_point.second);
	auto e = gr[from_block.first][from_block.second][to_block];
	auto dst = bfs_grid(from_point.first, from_point.second, [&](int r, int c) {
		return e.from == make_pair(r, c);
	});
	assert(dst.first != -1);
	get_back_path(from_point, dst);
	grid_path.push_back(string("O") + find_rel_place(e.from.first, e.from.second, e.to.first, e.to.second));

	auto closest_wall = bfs_grid(dst.first, dst.second, [&](int r, int c) {
		for (int i = 0; i < 4; ++i)
			if (grid[r + dr[i]][c + dc[i]] == 'W') return true;
		return false;
	});
	if (closest_wall.first == -1) {
		cout << "-1 -1";
		exit(0);
	}
	get_back_path(dst, closest_wall);
	for (int i = 0; i < 4; ++i) 
		if (grid[closest_wall.first + dr[i]][closest_wall.second + dc[i]] == 'W') {
			grid_path.emplace_back(string("B") + ds[i]);
			grid_path.emplace_back(string("M" + ds[i]));
			break;
		}
	return e.to;
}

int main() {
	cin.tie(0);
	ios_base::sync_with_stdio(0);

	cin >> n >> m;
	for (int i = 0; i < n; ++i) cin >> grid[i];

	cin >> sr >> sc >> fr >> fc;
	--sr, --sc, --fr, --fc;

	for (int i = 0; i < n; ++i)
		for (int f = 0; f < m; ++f)
			dsu[i][f] = { i, f };

	for (int i = 1; i < n - 1; ++i)
		for (int f = 1; f < m - 1; ++ f) {
			if (grid[i][f] != '.') continue;
			for (int dir = 0; dir < 4; ++ dir) {
				int nr = i + dr[dir], nc = f + dc[dir];
				if (grid[nr][nc] != '.') continue;
				join(i, f, nr, nc);
			}
		}

	for (int i = 1; i < n - 1; ++i) {
		int cur_wall = 0;
		for (int f = 1; f < m - 1; ++f) {
			if (grid[i][f] == 'G') continue;
			if (grid[i][f] == 'W') cur_wall = f;
			else {
				auto u = findp(i, cur_wall + 1);
				auto v = findp(i, f);
				if (gr[v.first][v.second].count(u)) continue;
				if (u == v) continue;
				gr[v.first][v.second][u] = edge(i, f, i, cur_wall + 1);
			}
		}

		cur_wall = m - 1;
		for (int f = m - 2; f > 0; --f) {
			if (grid[i][f] == 'G') continue;
			if (grid[i][f] == 'W') cur_wall = f;
			else {
				auto u = findp(i, cur_wall - 1);
				auto v = findp(i, f);
				if (gr[v.first][v.second].count(u)) continue;
				if (u == v) continue;
				gr[v.first][v.second][u] = edge(i, f, i, cur_wall - 1);
			}
		}
	}

	for (int f = 1; f < m - 1; ++f) {
		int cur_wall = 0;
		for (int i = 1; i < n - 1; ++i) {
			if (grid[i][f] == 'G') continue;
			if (grid[i][f] == 'W') cur_wall = i;
			else {
				auto u = findp(cur_wall + 1, f);
				auto v = findp(i, f);
				if (gr[v.first][v.second].count(u)) continue;
				if (u == v) continue;
				gr[v.first][v.second][u] = edge(i, f, cur_wall + 1, f);
			}
		}

		cur_wall = n - 1;
		for (int i = n - 2; i > 0; --i) {
			if (grid[i][f] == 'G') continue;
			if (grid[i][f] == 'W') cur_wall = f;
			else {
				auto u = findp(cur_wall - 1, f);
				auto v = findp(i, f);
				if (gr[v.first][v.second].count(u)) continue;
				if (u == v) continue;
				gr[v.first][v.second][u] = edge(i, f, cur_wall - 1, f);
			}
		}
	}

	memset(vis, 0, sizeof(vis));
	cur_ok = 1;
	auto s_block = findp(sr, sc), f_block = findp(fr, fc);
	bfs_block(s_block.first, s_block.second);

	if (vis[f_block.first][f_block.second] != cur_ok) {
		cout << "-1 -1";
		return 0;
	}

	vector<pair<int, int>> block_path;
	block_path.push_back(f_block);
	while (block_path.back() != s_block)
		block_path.push_back(parent[block_path.back().first][block_path.back().second]);

	auto cur_point = make_pair(sr, sc);
	for (int i = 0; i < (int)block_path.size() - 1; ++i) {
		cur_point = go(cur_point, block_path[i + 1]);
	}
	auto t = bfs_grid(cur_point.first, cur_point.second, [&](int r, int c) { return r == fr and c == fc; });
	if (t.first == -1) {
		cout << "-1 -1";
		return 0;
	}

	get_back_path(cur_point, t);
	cout << dis[f_block.first][f_block.second] << ' ' << grid_path.size() << '\n';
	for (auto s : grid_path) cout << s << '\n';

	return 0;
}