//#include <bits/stdc++.h>
#include <iostream>
#include <vector>
#include <stack>
#include <unordered_map>
#include <algorithm>

using namespace std;

const int MAXN = 2e5 + 7;
const long double eps = 1e-9;

bool ls(long double a, long double b, bool upper) {
    return (a < b - eps && upper) || (a > b + eps && !upper);
}

vector<pair<long double, int>> convex_hull(const vector<pair<long double, long double>>& lines, bool upper) {
    int n = lines.size();
    vector<int> p(n);
    for (int i = 0; i < n; i++) {
        p[i] = i;
    }


    auto cmp = [&](int i, int j) {
        return ls(lines[j].first, lines[i].first, upper) || (!ls(lines[i].first, lines[j].first, upper) && ls(lines[i].second, lines[j].second, upper));
    };
    sort(p.begin(), p.end(), cmp);

    vector<pair<long double, int>> ans;
    for (int i = 0; i < n; i++) {
        int j = p[i];
        //cerr << lines[j].first << " " << lines[j].second << endl;
        while (!ans.empty()) {
            auto k1 = lines[j];
            auto k = lines[ans.back().second];
            if (!ls(k1.first, k.first, upper)) {
                //cerr << "lol" << endl;
                break;
            }
            long double pos = (k1.second - k.second) / (k.first - k1.first);
            //cerr << pos << endl;
            if (pos > ans.back().first + eps) {
                ans.push_back({pos, j});
                break;
            }
            ans.pop_back();
        }
        if (ans.empty()) {
            ans.push_back({0, j});
        }
    }

    //cerr << endl;

    /*for (auto lol: ans) {
        cerr << lol.first << " " << lines[lol.second].first << " " << lines[lol.second].second << endl;
    }
    cerr << endl;*/

    return ans;
}

int main() {
#ifdef LOCAL
    freopen("input.txt", "r", stdin);
    freopen("output.txt", "w", stdout);
#endif
    ios::sync_with_stdio(0);
    cin.tie(0);
    cout.tie(0);

    int X, Y, n;
    cin >> X >> Y >> n;
    vector<pair<int, int>> p(n);

    for (int i = 0; i < n; i++) {
        cin >> p[i].first >> p[i].second;
    }

    vector<pair<long double, long double>> upper;
    vector<pair<long double, long double>> lower;
    upper.push_back({0, Y});
    lower.push_back({0, 0});
    long double minx = 0;
    long double maxx = X;

    for (int j = 1; j < n; j++) {
        long long ax = 2 * (p[j].first - p[0].first);
        long long ay = 2 * (p[j].second - p[0].second);
        long double c = (p[0].first * p[0].first + p[0].second * p[0].second) - (p[j].first * p[j].first + p[j].second * p[j].second);
        if (ay == 0) {
            if (ax > 0) {
                maxx = min(maxx, -c / (long double) ax);
            }
            if (ax < 0) {
                minx = max(minx, -c / (long double) ax);
            }
        } else if (ay > 0) {
            long double k = -ax / (long double) ay;
            long double b = -c / (long double) ay;
            upper.push_back({k, b});
        } else if (ay < 0) {
            long double k = -ax / (long double) ay;
            long double b = -c / (long double) ay;
            lower.push_back({k, b});
        }
    }

    auto upper_hull = convex_hull(upper, 1);
    auto lower_hull = convex_hull(lower, 0);

    long long ans = 0;

    int lower_it = 0;
    int upper_it = 0;

    for (int x = 0; x <= X; x++) {
        if ((x < minx - eps) || (x > maxx + eps)) continue;
        while (upper_it + 1 < upper_hull.size() && x > upper_hull[upper_it + 1].first + eps) upper_it++;
        while (lower_it + 1 < lower_hull.size() && x > lower_hull[lower_it + 1].first + eps) lower_it++;
        auto k_upper = upper[upper_hull[upper_it].second];
        auto k_lower = lower[lower_hull[lower_it].second];
        long double upper_y = k_upper.first * x + k_upper.second;
        long double lower_y = k_lower.first * x + k_lower.second;
        int upper_y_int = int(upper_y + eps);
        int lower_y_int = int(lower_y + 1 - eps);
        //cerr << lower_y_int << " " << upper_y_int << endl;
        if (upper_y_int >= lower_y_int) {
            ans += upper_y_int - lower_y_int + 1;
        }
    }

    cout << ans;
    return 0;
}