#ifdef LOCAL
#define _GLIBCXX_DEBUG
#endif
#include <bits/stdc++.h>

using namespace std;

using ll = long long;

mt19937 mt(736);

const int dx[] = {-1, +1, 0, 0};
const int dy[] = {0, 0, -1, +1};
const char direction[] = "UDLR";

void bfs (const vector<string> &grid, const int v, vector<int> &used, const int h)
{
	const int m = int(grid[0].size());

	queue<int> q;
	q.push(v);
	used[v] = h;

	while (!q.empty())
	{
		const int cur = q.front(); q.pop();
		const int cx = cur / m, cy = cur % m;

		for (int d = 0; d < 4; d++)
		{
			const int nx = cx + dx[d], ny = cy + dy[d];
			if (grid[nx][ny] == '.')
			{
				const int dest = nx * m + ny;
				if (used[dest] == -1)
				{
					used[dest] = h;
					q.push(dest);
				}
			}
		}
	}
}

struct edge
{
	int from, to;
	char dir;
};

void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int n, m;
	cin >> n >> m;

	vector<string> grid(n);
	for (auto &s : grid)
		cin >> s;

	int rs, cs, re, ce;
	cin >> rs >> cs >> re >> ce;
	--rs, --cs, --re, --ce;

	auto code = [&] (int x, int y)
	{
		return x * m + y;
	};

	vector<int> cmp(n * m, -1);
	int h = 0;

	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			if (grid[i][j] == '.' && cmp[code(i, j)] == -1)
				bfs(grid, code(i, j), cmp, h++);
		}
	}

	vector<vector<pair<int, edge>>> comp_g(h);

	vector<vector<int>> left(n, vector<int>(m));
	auto down = left, up = left, right = left;

	cerr << "before" << endl;

	for (int i = 0; i < n; i++)
	{
		left[i][0] = 0;
		for (int j = 1; j < m; j++)
			left[i][j] = (grid[i][j] == 'W' ? j : left[i][j - 1]);

		right[i][m - 1] = m - 1;
		for (int j = m - 2; j >= 0; j--)
			right[i][j] = (grid[i][j] == 'W' ? j : right[i][j + 1]);
	}

	cerr << "mid" << endl;

	for (int j = 0; j < m; j++)
	{
		up[0][j] = 0;
		for (int i = 1; i < n; i++)
			up[i][j] = (grid[i][j] == 'W' ? i : up[i - 1][j]);

		down[n - 1][j] = n - 1;
		for (int i = n - 2; i >= 0; i--)
			down[i][j] = (grid[i][j] == 'W' ? i : down[i + 1][j]);
	}

	cerr << "After" << endl;

	for (int i = 0; i < n; i++)
	{
		for (int j = 0; j < m; j++)
		{
			auto add = [&] (int x1, int y1, int x2, int y2, char symb)
			{
				const int from = cmp[code(x1, y1)];
				const int to = cmp[code(x2, y2)];
				if (to != -1)
					comp_g[from].emplace_back(to, edge{code(x1, y1), code(x2, y2), symb});
			};

			if (grid[i][j] == '.')
			{
				{
					const int nj = right[i][j];
					assert(nj > j);
					add(i, j, i, nj - 1, 'R');
				}

				{
					const int nj = left[i][j];
					assert(nj < j);
					add(i, j, i, nj + 1, 'L');
				}

				{
					const int ni = up[i][j];
					assert(ni < i);
					add(i, j, ni + 1, j, 'U');
				}

				{
					const int ni = down[i][j];
					assert(ni > i);
					add(i, j, ni - 1, j, 'D');
				}
			}
		}
	}

	const int comp_s = cmp[code(rs, cs)];
	const int comp_f = cmp[code(re, ce)];

	vector<int> cmp_path;
	vector<edge> edge_seq;

	{
		queue<int> q;
		vector<int> par(h, -2);
		vector<edge> par_edge(h);

		{
			q.push(comp_s);
			par[comp_s] = -1;
		}

		while (!q.empty())
		{
			const int cur = q.front(); q.pop();

			for (auto dest_pr : comp_g[cur])
			{
				const int dest = dest_pr.first;
				if (par[dest] == -2)
				{
					par[dest] = cur;
					par_edge[dest] = dest_pr.second;
					q.push(dest);
				}
			}
		}

		if (par[comp_f] == -2)
		{
			cout << "-1 -1" << endl;
			return;
		}

		int v = comp_f;
		while (v != -1)
		{
			cmp_path.push_back(v);
			if (v != comp_s)
				edge_seq.push_back(par_edge[v]);
			v = par[v];
		}

		assert(cmp_path.back() == comp_s);
		reverse(cmp_path.begin(), cmp_path.end());
		reverse(edge_seq.begin(), edge_seq.end());
	}


	char parity = 'B';
	int portals = 0, steps = 0;
	vector<string> ans;

	auto just_move = [&] (char dir)
	{
		steps++;
		ans.push_back(string(1, 'M') + string(1, dir));
	};

	auto decode = [&] (const int x)
	{
		return pair<int, int>(x / m, x % m);
	};

	auto shoot_portal = [&] (char dir)
	{
		portals++;
		ans.push_back(string(1, parity) + string(1, dir));
		parity ^= 'B' ^ 'O';
	};

	vector<int> dist(n * m, -1), par(n * m, -1);
	vector<char> par_move(n * m, -1);

	auto go = [&](int fx, int fy, int tx, int ty) {
		const int from = code(fx, fy);
		const int to = code(tx, ty);

		vector<int> q;
		q.push_back(from);
		dist[from] = 0;

		for (int ptr = 0; ptr < int(q.size()); ptr++)
		{>
			const int cur = q[ptr];
			const int cx = cur / m, cy = cur % m;

			for (int d = 0; d < 4; d++)
			{
				const int nx = cx + dx[d], ny = cy + dy[d];
				const int dest = code(nx, ny);

				if (dist[dest] == -1 && grid[nx][ny] == '.')
				{
					dist[dest] = dist[cur] + 1;
					q.push_back(dest);
					par[dest] = cur;
					par_move[dest] = direction[d];
				}
			}
		}

		assert(dist[to] != -1);
		for (int v : q)
			dist[v] = -1;

		string path;
		{
			int v = to;
			while (v != from)
			{
				path += par_move[v];
				v = par[v];
			}

			reverse(path.begin(), path.end());
		}

		for (char ch : path)
			just_move(ch);
	};

	if (comp_f == comp_s)
		go(rs, cs, re, ce);
	else
	{
		int rp = -1, cp = -1;
		char dir = -1;

		for (int i = 0; i < n; i++)
		{
			for (int j = 0; j < m; j++)
			{
				if (cmp[code(i, j)] == comp_s)
				{
					for (int d = 0; d < 4; d++)
					{
						const int ni = i + dx[d], nj = j + dy[d];
						if (grid[ni][nj] == 'W')
						{
							rp = i;
							cp = j;
							dir = direction[d];
						}
					}
				}
			}
		}

		if (dir == -1)
		{
			cout << "-1 -1" << endl;
			return;
		}

		int rto, cto;
		tie(rto, cto) = decode(edge_seq[0].from);
		go(rs, cs, rto, cto);
		shoot_portal(edge_seq[0].dir);
		go(rto, cto, rp, cp);
		shoot_portal(dir);
		just_move(dir);

		dir = edge_seq[0].dir;
		parity ^= 'B' ^ 'O';

		int r = -1, c = -1;
		tie(r, c) = decode(edge_seq[0].to);

		for (int i = 1; i < int(edge_seq.size()); i++)
		{
			tie(rto, cto) = decode(edge_seq[i].from);
			go(r, c, rto, cto);
			shoot_portal(edge_seq[i].dir);
			go(rto, cto, r, c);
			just_move(dir);
			dir = edge_seq[i].dir;

			tie(r, c) = decode(edge_seq[i].to);
		}

		go(r, c, re, ce);
	}

	cout << portals << ' ' << steps << endl;
	assert(int(ans.size()) == portals + steps);
	for (auto s : ans)
		cout << s << "\n";
	cout.flush();
}

int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	cout << fixed;

#ifdef LOCAL
	ifstream fin("../input.txt");

	solve(fin);

	cout << "clock: " << clock() / (double) CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
