#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;
using halfplane = pair<complex<ld>, complex<ld>>;

mt19937 mt(736);

template<class T>
T sqr(T x)
{
	return x * x;
}

ld scalar(complex<ld> a, complex<ld> b)
{
	return a.real() * b.real() + a.imag() * b.imag();
}


complex<ld> intersect(halfplane a, halfplane b)
{
	auto a1 = a.first.real();
	auto a2 = b.first.real();
	auto b1 = a.first.imag();
	auto b2 = b.first.imag();
	auto c1 = scalar(a.first, a.second);
	auto c2 = scalar(b.first, b.second);

	auto det = a1 * b2 - a2 * b1;

	assert(det != 0);

	complex<ld> ans = {-(b1 * c2 - b2 * c1) / det, (a1 * c2 - a2 * c1) / det};

	return ans;
}


void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int m, n, k;

	cin >> m >> n >> k;
	m++;
	n++;

	vector<complex<ld>> p(k);

	for (auto &it : p)
	{
		ld x, y;

		cin >> x >> y;

		it = {x, y};
	}

	vector<halfplane> hp;
	hp.reserve(k - 1 + 4);

	for (int i = 1; i < k; i++)
		hp.emplace_back(p.front() - p[i], (p.front() + p[i]) / (ld)2);
	hp.emplace_back(complex<ld>{0, 1}, complex<ld>{0, 0});
	hp.emplace_back(complex<ld>{1, 0}, complex<ld>{0, 0});
	hp.emplace_back(complex<ld>{0, -1}, complex<ld>{m - 1., n - 1.});
	hp.emplace_back(complex<ld>{-1, 0}, complex<ld>{m - 1., n - 1.});

	sort(hp.begin(), hp.end(), [](const auto &a, const auto &b) {
		return atan2(a.first.imag(), a.first.real()) < atan2(b.first.imag(), b.first.real());
	});

	{
		auto tmp = hp;

		hp.insert(hp.end(), tmp.begin(), tmp.end());
		hp.insert(hp.end(), tmp.begin(), tmp.end());
		hp.insert(hp.end(), tmp.begin(), tmp.end());
	}

	vector<int> bnd;

	auto better = [](halfplane a, halfplane b) -> bool {
		if (scalar(a.first, b.first) <= 0 ||
		    a.first.real() * b.first.imag() - a.first.imag() * b.first.real() != 0)
			return false;
		return scalar(a.first, a.second) >= scalar(a.first, b.second);
	};

	for (int i = 0; i < hp.size(); i++)
	{
		while ((!bnd.empty() && better(hp[i], hp[bnd.back()])) ||
		       (bnd.size() > 1 && scalar(hp[i].first, hp[i].second) >
		                          scalar(hp[i].first, intersect(hp[bnd.back()], hp[bnd[bnd.size() - 2]]))))
			bnd.pop_back();

		if (bnd.empty() || !better(hp[bnd.back()], hp[i]))
			bnd.push_back(i);
	}

	vector<int> x0(m, 0), x1(m, n);
	vector<bool> marked(m);

	map<pair<int, int>, int> pos;

	int st, fn;

	for (int i = 1; i < bnd.size(); i++)
	{
		pair<int, int> cur = {bnd[i] % (hp.size() / 4), bnd[i - 1] % (hp.size() / 4)};

		if (pos.count(cur))
		{
			st = pos[cur];
			fn = i;

			break;
		}
		else
			pos[cur] = i;
	}

	for (int i = st; i < fn; i++)
	{
		complex<ld> fs = intersect(hp[bnd[i]], hp[bnd[i - 1]]),
				sn = intersect(hp[bnd[i]], hp[bnd[i + 1]]);

		if (hp[bnd[i]].first.imag() < 0)
		{
			for (int i = ceil(min(fs.real(), sn.real())); i <= max(fs.real(), sn.real()); i++)
			{
				auto y = (sn.imag() * (fs.real() - i) + fs.imag() * (i - sn.real())) / (fs.real() - sn.real());

				x1[i] = min(x1[i], (int) floor(y));
				marked[i] = true;
			}
		}
		else
		{
			for (int i = ceil(min(fs.real(), sn.real())); i <= max(fs.real(), sn.real()); i++)
			{
				auto y = (sn.imag() * (fs.real() - i) + fs.imag() * (i - sn.real())) / (fs.real() - sn.real());

				x0[i] = max(x0[i], (int) ceil(y));
				marked[i] = true;
			}
		}
	}

	ll ans = 0;

	for (int i = 0; i < x0.size(); i++)
		if (marked[i])
			ans += max(0, x1[i] + 1 - x0[i]);

	cout << ans << endl;
}


int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	cout << fixed;

#ifdef LOCAL
	ifstream fin("../input.txt");

	solve(fin);

	cout << "clock: " << clock() / (ld) CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
