#include <bits/stdc++.h>

using namespace std;

using ll = long long;
using ld = long double;
using halfplane = pair<complex<ld>, complex<ld>>;

const ld eps = 1e-9;

mt19937 mt(736);

template<class T>
T sqr(T x)
{
	return x * x;
}

ld scalar(complex<ld> a, complex<ld> b)
{
	return a.real() * b.real() + a.imag() * b.imag();
}


complex<ld> intersect(halfplane a, halfplane b)
{
	auto a1 = a.first.real();
	auto a2 = b.first.real();
	auto b1 = a.first.imag();
	auto b2 = b.first.imag();
	auto c1 = scalar(a.first, a.second);
	auto c2 = scalar(b.first, b.second);

	auto det = a1 * b2 - a2 * b1;

	assert(det != 0);

	complex<ld> ans = {-(b1 * c2 - b2 * c1) / det, (a1 * c2 - a2 * c1) / det};

	return ans;
}


void solve(istream &cin = std::cin, ostream &cout = std::cout)
{
	int m, n, k;

	cin >> m >> n >> k;
	m++;
	n++;

	vector<complex<ld>> p(k);

	for (auto &it : p)
	{
		ld x, y;

		cin >> x >> y;

		it = {x, y};
	}

	vector<halfplane> hp;
	hp.reserve(k - 1 + 4);

	for (int i = 1; i < k; i++)
		hp.emplace_back(p.front() - p[i], (p.front() + p[i]) / (ld) 2);
	hp.emplace_back(complex<ld>{0, 1}, complex<ld>{0, 0});
	hp.emplace_back(complex<ld>{1, 0}, complex<ld>{0, 0});
	hp.emplace_back(complex<ld>{0, -1}, complex<ld>{m - 1., n - 1.});
	hp.emplace_back(complex<ld>{-1, 0}, complex<ld>{m - 1., n - 1.});

	sort(hp.begin(), hp.end(), [](const auto &a, const auto &b) {
		return atan2(a.first.imag(), a.first.real()) < atan2(b.first.imag(), b.first.real());
	});

	{
		auto tmp = hp;

		hp.insert(hp.end(), tmp.begin(), tmp.end());
		hp.insert(hp.end(), tmp.begin(), tmp.end());
		hp.insert(hp.end(), tmp.begin(), tmp.end());
	}

	vector<int> bnd;

	auto better = [](halfplane a, halfplane b) -> bool {
		if (scalar(a.first, b.first) <= 0 ||
		    a.first.real() * b.first.imag() - a.first.imag() * b.first.real() != 0)
			return false;
		return scalar(a.first, a.second) >= scalar(a.first, b.second);
	};

	for (int i = 0; i < hp.size(); i++)
	{
		while ((!bnd.empty() && better(hp[i], hp[bnd.back()])) ||
		       (bnd.size() > 1 &&
		        scalar(hp[i].first, hp[i].second) >=
		        scalar(hp[i].first, intersect(hp[bnd.back()], hp[bnd[bnd.size() - 2]]))))
			bnd.pop_back();

		if (bnd.empty() || !better(hp[bnd.back()], hp[i]))
			bnd.push_back(i);
	}

	vector<int> x0(m, 0), x1(m, n - 1);
	vector<bool> marked(m);

	map<pair<int, int>, int> pos;

	int st, fn;

	for (int i = 1; i < bnd.size(); i++)
	{
		pair<int, int> cur = {bnd[i] % (hp.size() / 4), bnd[i - 1] % (hp.size() / 4)};

		if (pos.count(cur))
		{
			st = pos[cur];
			fn = i;

			break;
		}
		else
			pos[cur] = i;
	}

	for (int i = st; i < fn; i++)
	{
		complex<ld> fs = intersect(hp[bnd[i]], hp[bnd[i - 1]]),
				sn = intersect(hp[bnd[i]], hp[bnd[i + 1]]);

		//cerr << fs << '\t' << sn << endl;

		if (hp[bnd[i]].first.imag() != 0)
		{
			if (hp[bnd[i]].first.imag() < 0)
			{
				for (int i = ceil(min(fs.real(), sn.real())); i <= max(fs.real(), sn.real()); i++)
				{
					auto y = (sn.imag() * (fs.real() - i) + fs.imag() * (i - sn.real())) / (fs.real() - sn.real());
					y = abs(y);

					x1[i] = min(x1[i], (int) floor(y + eps));
					marked[i] = true;
				}
			}
			else
			{
				for (int i = ceil(min(fs.real(), sn.real())); i <= max(fs.real(), sn.real()); i++)
				{
					auto y = (sn.imag() * (fs.real() - i) + fs.imag() * (i - sn.real())) / (fs.real() - sn.real());
					y = abs(y);

					x0[i] = max(x0[i], (int) ceil(y - eps));
					marked[i] = true;
				}
			}
		}
	}

	//cerr << endl << endl << endl << endl;

	ll ans = 0;

	for (int i = 0; i < x0.size(); i++)
		if (marked[i])
			ans += max(0, x1[i] + 1 - x0[i]);

	cout << ans << endl;
}


void stress(istream &cin = std::cin, ostream &cout = std::cout)
{
	int m, n, k;

	cin >> m >> n >> k;
	m++;
	n++;

	vector<pair<int, int>> p(k);

	for (auto &it : p)
	{
		ld x, y;

		cin >> x >> y;

		it = {x, y};
	}

	ll ans = 0;

	for (int y = 0; y < n; y++)
		for (int x = 0; x < m; x++)
		{
			int q = 0;

			for (int i = 1; i < k; i++)
				if (sqr(x - (ll) p[i].first) + sqr(y - (ll) p[i].second) <
				    sqr(x - (ll) p[q].first) + sqr(y - (ll) p[q].second))
					q = i;

			if (q == 0)
				ans++;
		}

	cout << ans << endl;
}


void gen(ostream &cout = std::cout)
{
	const int n = 4, m = 3, k = 2;

	cout << m << ' ' << n << ' ' << k << endl;

	uniform_int_distribution<int> x(0, m), y(0, n);

	vector<pair<int, int>> q;

	while (q.size() < k)
	{
		while (q.size() < k)
			q.emplace_back(x(mt), y(mt));

		sort(q.begin(), q.end());
		q.erase(unique(q.begin(), q.end()), q.end());
	}

	shuffle(q.begin(), q.end(), mt);

	for (auto it : q)
		cout << it.first << ' ' << it.second << endl;
}


int main()
{
	ios_base::sync_with_stdio(false);
	cin.tie(nullptr);

	cout << fixed;

#ifdef LOCAL
	ifstream fin("../input.txt");

	solve(fin);

	int cnt = 0;

	while (true)
	{
		stringstream ss, in1, in2, out1, out2;

		gen(ss);

		in1 << ss.str ();
		in2 << ss.str ();

		solve(in1, out1);
		stress(in2, out2);

		if (out1.str () != out2.str())
		{
			cout << ss.str() << endl;
			cout << out1.str() << endl;
			cout << out2.str() << endl;

			break;
		}
		else if (++cnt % 100 == 0)
			cout << cnt << endl;
	}

	cout << "clock: " << clock() / (ld) CLOCKS_PER_SEC << endl;
#else
	solve();
#endif

	return 0;
}
